#!/bin/sh

. /usr/share/acpi-support/power-funcs

getState;
getXuser;

checkStateChanged;

sleep 5;
grep -q off-line /proc/acpi/ac_adapter/*/state
if [ $? = 0 ]
        then
        xset dpms 0 0 120
        $LAPTOP_MODE start
        $HDPARM -S 12 /dev/hda
        $HDPARM -B 1 /dev/hda
        su $user -c "xscreensaver-command -throttle" &
else
        xset dpms 0 0 600
        $LAPTOP_MODE stop
        $HDPARM -S 0 /dev/hda
        $HDPARM -B 255 /dev/hda
        su $user -c "xscreensaver-command -unthrottle" &
fi
